==> spammaster-8.x-1.77.tar.gz: spammaster/src/SpamMasterCollectService.php <==
<?php

namespace Drupal\spammaster;

use Symfony\Component\HttpFoundation\RequestStack;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class service.
 */
class SpamMasterCollectService {

  /**
   * Symfony\Component\HttpFoundation\RequestStack definition.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected $requestStack;

  /**
   * The form class.
   *
   * @var \Drupal\Core\Form\FormInterface
   */
  protected $collectnow;

  /**
   * {@inheritdoc}
   */
  public function __construct(RequestStack $requestStack) {
    $this->requestStack = $requestStack;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('request_stack')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function spamMasterGetCollect($collectnow) {

    $this->collectnow = $collectnow;
    // Get remote ip.
    $spammasterip = substr($this->requestStack->getCurrentRequest()->getClientIp(), 0, 48);
    // Get remote agent.
    if (isset($_SERVER['HTTP_USER_AGENT'])) {
      $spammasteragent = htmlentities($_SERVER['HTTP_USER_AGENT'], ENT_QUOTES, 'UTF-8');
    }
    else {
      $spammasteragent = 'Sniffer';
    }
    // Get remote referrer.
    if (isset($_SERVER['HTTP_REFERER'])) {
      $spammasterreferer = substr(htmlentities($_SERVER['HTTP_REFERER'], ENT_QUOTES, 'UTF-8'), 0, 360);
    }
    else {
      $spammasterreferer = 'Direct';
    }
    // Get destination url.
    if (isset($_SERVER['REQUEST_SCHEME'])) {
      $spam_request_scheme = htmlentities($_SERVER['REQUEST_SCHEME'], ENT_QUOTES, 'UTF-8');
    }
    else {
      $spam_request_scheme = 'false';
    }
    if (isset($_SERVER['SERVER_NAME'])) {
      $spam_server_name = htmlentities($_SERVER['SERVER_NAME'], ENT_QUOTES, 'UTF-8');
    }
    else {
      $spam_server_name = 'false';
    }
    if (isset($_SERVER['REQUEST_URI'])) {
      $spam_request_uri = htmlentities($_SERVER['REQUEST_URI'], ENT_QUOTES, 'UTF-8');
    }
    else {
      $spam_request_uri = '/false';
    }
    $spammasterurl = substr($spam_request_scheme . '://' . $spam_server_name . $spam_request_uri, 0, 360);

    return [
      'spammasterip'      => $spammasterip,
      'spammasteragent'   => $spammasteragent,
      'spammasterreferer' => $spammasterreferer,
      'spammasterurl'     => $spammasterurl,
    ];

  }

}

==> spammaster-8.x-1.82.tar.gz: spammaster/src/SpamMasterCollectService.php <==
<?php

namespace Drupal\spammaster;

use Symfony\Component\HttpFoundation\RequestStack;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class service.
 */
class SpamMasterCollectService {

  /**
   * Symfony\Component\HttpFoundation\RequestStack definition.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected $requestStack;

  /**
   * The form class.
   *
   * @var \Drupal\Core\Form\FormInterface
   */
  protected $collectnow;

  /**
   * {@inheritdoc}
   */
  public function __construct(RequestStack $requestStack) {
    $this->requestStack = $requestStack;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('request_stack')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function spamMasterGetCollect($collectnow) {

    $this->collectnow = $collectnow;
    // Get remote ip.
    $spammasterip = substr($this->requestStack->getCurrentRequest()->getClientIp(), 0, 48);
    // Get remote agent.
    if (isset($_SERVER['HTTP_USER_AGENT'])) {
      $spammasteragent = htmlentities($_SERVER['HTTP_USER_AGENT'], ENT_QUOTES, 'UTF-8');
    }
    else {
      $spammasteragent = 'Sniffer';
    }
    // Get remote referrer.
    if (isset($_SERVER['HTTP_REFERER'])) {
      $spammasterreferer = substr(htmlentities($_SERVER['HTTP_REFERER'], ENT_QUOTES, 'UTF-8'), 0, 360);
    }
    else {
      $spammasterreferer = 'Direct';
    }
    // Get destination url.
    if (isset($_SERVER['REQUEST_SCHEME'])) {
      $spam_request_scheme = htmlentities($_SERVER['REQUEST_SCHEME'], ENT_QUOTES, 'UTF-8');
    }
    else {
      $spam_request_scheme = 'https';
    }
    if (isset($_SERVER['SERVER_NAME'])) {
      $spam_server_name = htmlentities($_SERVER['SERVER_NAME'], ENT_QUOTES, 'UTF-8');
    }
    else {
      $spam_server_name = 'false';
    }
    if (isset($_SERVER['REQUEST_URI'])) {
      $spam_request_uri = htmlentities($_SERVER['REQUEST_URI'], ENT_QUOTES, 'UTF-8');
    }
    else {
      $spam_request_uri = '/false';
    }
    $spammasterurl = substr($spam_request_scheme . '://' . $spam_server_name . $spam_request_uri, 0, 360);

    return [
      'spammasterip'      => $spammasterip,
      'spammasteragent'   => $spammasteragent,
      'spammasterreferer' => $spammasterreferer,
      'spammasterurl'     => $spammasterurl,
    ];

  }

}
